InspectorServerInit class

Constructors

InspectorServerInit(int contextId, int port, String address, String bundleURL)

Properties

address → String
final
bundleURL → String
final
contextId → int
final
hashCode → int
The hash code for this object.
no setterinherited
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited